@@ -1,8 +1,9 @@
-__author__ = "Shyue Ping Ong, Anubhav Jain, Michael Kocher, " + \
-             "Geoffroy Hautier, William Davidson Richard, Dan Gunter, " + \
-             "Shreyas Cholia, Vincent L Chevrier, Rickard Armiento"
-__date__ = "Jan 14 2013"
-__version__ = "2.4.2"
+__author__ = ", ".join(["Shyue Ping Ong", "Anubhav Jain", "Geoffroy Hautier",
+                        "William Davidson Richard", "Stephen Dacek",
+                        "Michael Kocher", "Dan Gunter", "Shreyas Cholia",
+                        "Vincent L Chevrier", "Rickard Armiento"])
+__date__ = "Jan 27 2013"
+__version__ = "2.5.0"
 
 #Useful aliases for commonly used objects and modules.
 
