@@ -81,20 +81,6 @@ class TransformedStructure(MSONable):
         for t in transformations:
             self.append_transformation(t)
 
-    def undo_last_transformation(self):
-        """
-        .. deprecated:: v2.2.2
-        """
-        warnings.warn("Deprecated. Use undo_last_change.", DeprecationWarning)
-        self.undo_last_change()
-
-    def redo_next_transformation(self):
-        """
-        .. deprecated:: v2.2.2
-        """
-        warnings.warn("Deprecated. Use redo_last_change.", DeprecationWarning)
-        self.redo_next_change()
-
     def undo_last_change(self):
         """
         Undo the last change in the TransformedStructure.
