@@ -255,8 +255,8 @@ class PDPlotter(object):
 
     def plot_chempot_range_map(self, elements):
         """
-        Plot chemical potential range map. Currently works only for 3-component
-        PDs.
+        Plot the chemical potential range map. Currently works only for
+        3-component PDs.
 
         Args:
             elements:
@@ -265,6 +265,22 @@ class PDPlotter(object):
                 phases wrt to uLi and uO, you will supply
                 [Element("Li"), Element("O")]
         """
+        self.get_chempot_range_map_plot(elements).show()
+
+    def get_chempot_range_map_plot(self, elements):
+        """
+        Returns a plot of the chemical potential range map. Currently works
+        only for 3-component PDs.
+
+        Args:
+            elements:
+                Sequence of elements to be considered as independent variables.
+                E.g., if you want to show the stability ranges of all Li-Co-O
+                phases wrt to uLi and uO, you will supply
+                [Element("Li"), Element("O")]
+        Returns:
+            A matplotlib plot object.
+        """
 
         plt = get_publication_quality_plot(12, 8)
         analyzer = PDAnalyzer(self._pd)
@@ -351,8 +367,7 @@ class PDPlotter(object):
         plt.ylabel("$\mu_{{{0}}} - \mu_{{{0}}}^0$ (eV)"
                    .format(el1.symbol))
         plt.tight_layout()
-        plt.savefig("chempot.eps")
-        plt.show()
+        return plt
 
     def get_contour_pd_plot(self):
         """
